@@ -1,7 +1,7 @@
 import tensorflow as tf
 import warnings
 from keras import layers
-from keras.utils.generic_utils import register_keras_serializable
+from keras.saving.object_registration import register_keras_serializable
 from keras.utils.tf_utils import shape_type_conversion
 
 
